interface Cancelable {
    cancel(): void;
}
interface Options {
    leading?: boolean;
    trailing?: boolean;
}
/**
 * Returns a function, that, when invoked, will only be triggered at most once
 * during a given window of time. Normally, the throttled function will run
 * as much as it can, without ever going more than once per `wait` duration;
 * but if you'd like to disable the execution on the leading edge, pass
 * `{leading: false}`. To disable execution on the trailing edge, ditto.
 */
declare const throttle: <T extends Function>(func: T, wait: number, options?: Options) => T & Cancelable;
export { throttle };
